# gradedoc

Grader for DOCX lab reports using comments.

## Installing

### Prerequisites

Make sure `python`, Windows Terminal, and AutoHotkey are installed. These links should get you started:

- [Python](https://www.python.org/downloads/)
- [AutoHotkey](https://www.autohotkey.com/)
- [Windows Terminal](https://www.microsoft.com/en-us/p/windows-terminal/9n0dx20hk701)

If you're not familiar with configuring these tools, just accept the default options when installing.

### Install `pipx`

```PowerShell
py -m pip install pipx
py -m pipx ensurepath
```

### Install `gradedoc`

```PowerShell
py -m pipx install gradedoc
```
